@@ -3,7 +3,7 @@ import sys
 from pyrogram import Client
 
 def restart():
-    os.execvp(sys.executable, [sys.executable, "-m", "KillerXBase"])
+    os.execvp(sys.executable, [sys.executable, "-m", "DarkWeb"])
 
 async def join(client):
     try:
