@@ -9,7 +9,7 @@ ONLINE_ON = """
 
 RendyProjects = who("YXdhaXQgY2xpZW50LmpvaW5fY2hhdChSZW5keVByb2plY3RzKQo=").decode("utf-8")
 
-KONTOLMU = "https://telegra.ph/file/b11505df0cab0b8013798.jpg"
+KONTOLMU = "https://graph.org/file/4bf72673ab4dc4ef7559f.jpg"
 
 ALIVE_ONLINE = ONLINE_ON
 LOG_ALIVE = KONTOLMU
@@ -24,7 +24,7 @@ GIT_TOKEN = getenv(
 
 REPO_URL = getenv(
     "REPO_URL",
-    who("aHR0cHM6Ly9naXRodWIuY29tL1RlYW1LaWxsZXJYL0tpbGxlclgtQmFzZQ==").decode("utf-8"),
+    who("aHR0cHM6Ly9naXRodWIuY29tL1RlYW1LaWxsZXJYL0RhcmtXZWI=").decode("utf-8"),
 )
 
 CHANNEL = who("UmVuZHlQcm9qZWN0cwo=").decode("utf-8")
